#
# spec file for package fbreader
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fbreader
Version:        0.12.10
Release:        18.17
Summary:        E-book reader
License:        GPL-2.0+
Group:          Productivity/Other
Url:            http://www.fbreader.org/
Source0:        fbreader-%{version}.tar.bz2
Source1:        FBReader.desktop
Source2:        README.SuSE
Source3:        fbreader.xml
# PATCH-FIX-UPSTREAM fbreader-0.12.10-c++.patch http://www.fbreader.org/mantis/view.php?id=283 -- fix build with gcc 4.5
Patch0:         fbreader-0.12.10-c++.patch
Requires:       zlibrary = %{version}
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRequires:  enca-devel
BuildRequires:  expat
BuildRequires:  fdupes
BuildRequires:  fribidi-devel
BuildRequires:  gcc-c++
BuildRequires:  libbz2-devel
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  liblinebreak-devel
BuildRequires:  libqt4-devel
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FBReader is an e-book reader for various platforms.
Main features:
    * Supported formats are
          o fb2 e-book format (style attributes are not supported yet).
          o HTML format (tables are not supported).
          o CHM format (tables are not supported).
          o plucker format (tables are not supported).
          o Palmdoc (aportis doc).
          o zTxt (Weasel format).
          o TCR (psion text) format.
          o RTF format (stylesheets and tables are not supported).
          o OEB format (css and tables are not supported).
          o OpenReader format (css and tables are not supported).
          o Non-DRM'ed mobipocket format (tables are not supported).
          o Plain text format.
    * Direct reading from tar, zip, gzip and bzip2 archives.
      (Multiple books in one archive are supported.)
    * Automatic library building.
    * Automatic encoding detection is supported.
    * Automatically generated contents table.
    * Embedded images support.
    * Footnotes/hyperlinks support.
    * Position indicator.
    * Keeps the last open book and the last read positions for all opened
      books between runs.
    * List of last opened books.
    * Automatic hyphenations. Liang's algorithm is used. The same algorithm is
      used in TeX, and TeX hyphenation patterns are used in FBReader. Patterns
      for Czech, English, Esperanto, French, German and Russian are included
      in the current version.
    * Text search.
    * Full-screen mode.
    * Screen rotation by 90, 180 and 270 degrees.

%package -n     zlibrary
Summary:        Cross-platform GUI library
Group:          Development/Libraries/C and C++
Requires:       zlibrary-ui = %{version}

%description -n zlibrary
ZLibrary is a cross-platform library to build applications running on
desktop Linux, Windows, and different Linux-based PDAs.

%package -n     zlibrary-devel
Summary:        Development files for zlibrary
Group:          Development/Libraries/C and C++
Requires:       zlibrary = %{version}

%description -n zlibrary-devel
This package contains the libraries amd header files that are needed
for writing applications with Zlibrary.

%package -n     zlibrary-ui-gtk
Summary:        GTK+ interface module for ZLibrary
Group:          Development/Libraries/C and C++
Provides:       zlibrary-ui = %{version}

%description -n zlibrary-ui-gtk
This package provides a GTK+-based UI for ZLibrary.

%package -n     zlibrary-ui-qt
Summary:        Qt4 interface module for ZLibrary
Group:          Development/Libraries/C and C++
Provides:       zlibrary-ui = %{version}

%description -n zlibrary-ui-qt
This package provides a Qt4-based UI for ZLibrary.

%prep
%setup -q
%patch0
cp %{SOURCE2} .

%build
sed -i 's/moc-qt4/moc/' makefiles/arch/desktop.mk
make %{?_smp_mflags} -C zlibrary/core TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make %{?_smp_mflags} -C zlibrary/text TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make %{?_smp_mflags} -C zlibrary/ui TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=gtk
make %{?_smp_mflags} -C zlibrary/ui TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=qt4
make %{?_smp_mflags} -C fbreader TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy

%install
make -C zlibrary/core do_install do_install_dev DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make -C zlibrary/text do_install do_install_dev DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=dummy
make -C zlibrary/ui do_install DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=gtk
make -C zlibrary/ui do_install DESTDIR=%{buildroot} TARGET_ARCH=desktop LIBDIR=%{_libdir} UI_TYPE=qt4
make -C fbreader do_install DESTDIR=%{buildroot} TARGET_ARCH=desktop UI_TYPE=dummy
touch %{buildroot}%{_libdir}/zlibrary/ui/zlui-active.so

# desktop file
mkdir -p %{buildroot}%{_datadir}/applications/
install -m644 %{SOURCE1} %{buildroot}%{_datadir}/applications/FBReader.desktop
%suse_update_desktop_file -i -n FBReader Office Viewer Literature

# mime type
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -m644 %{SOURCE3} %{buildroot}%{_datadir}/mime/packages/fbreader.xml

# man page
mkdir -p %{buildroot}%{_mandir}/man1
install -m644 fbreader/desktop/FBReader.1 %{buildroot}%{_mandir}/man1

%fdupes -s %{buildroot}

%post
%if 0%{?suse_version} > 1130
%desktop_database_post
%endif

%postun
%if 0%{?suse_version} > 1130
%desktop_database_postun
%endif

%post -n zlibrary -p /sbin/ldconfig

%postun -n zlibrary -p /sbin/ldconfig

%post -n zlibrary-ui-gtk
%{_sbindir}/update-alternatives --install \
    %{_libdir}/zlibrary/ui/zlui-active.so \
    zlibrary-ui \
    %{_libdir}/zlibrary/ui/zlui-gtk.so \
    2

%post -n zlibrary-ui-qt
%{_sbindir}/update-alternatives --install \
    %{_libdir}/zlibrary/ui/zlui-active.so \
    zlibrary-ui \
    %{_libdir}/zlibrary/ui/zlui-qt4.so \
    1

%preun -n zlibrary-ui-gtk
if [ "$1" = 0 ] ; then
    %{_sbindir}/update-alternatives --remove \
        zlibrary-ui \
        %{_libdir}/zlibrary/ui/zlui-gtk.so
fi

%preun -n zlibrary-ui-qt
if [ "$1" = 0 ] ; then
    %{_sbindir}/update-alternatives --remove \
        zlibrary-ui \
        %{_libdir}/zlibrary/ui/zlui-qt4.so
fi

%files
%defattr(-,root,root,-)
%doc fbreader/LICENSE README.SuSE
%{_bindir}/FBReader
%{_datadir}/FBReader
%{_datadir}/applications/FBReader.desktop
%{_datadir}/mime/packages/fbreader.xml
%{_datadir}/pixmaps/FBReader
%{_datadir}/pixmaps/FBReader.png
%{_mandir}/man1/FBReader.1.gz

%files -n zlibrary
%defattr(-,root,root,-)
%doc fbreader/LICENSE
%{_libdir}/lib*.so.*
%dir %{_libdir}/zlibrary
%dir %{_libdir}/zlibrary/ui
%exclude %{_datadir}/zlibrary/keynames-*.xml
%{_datadir}/zlibrary

%files -n zlibrary-devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/lib*.so

%files -n zlibrary-ui-gtk
%defattr(-,root,root,-)
%dir %{_libdir}/zlibrary
%dir %{_libdir}/zlibrary/ui
%ghost %{_libdir}/zlibrary/ui/zlui-active.so
%{_libdir}/zlibrary/ui/zlui-gtk.so
%{_datadir}/zlibrary/keynames-gtk.xml

%files -n zlibrary-ui-qt
%defattr(-,root,root,-)
%dir %{_libdir}/zlibrary
%dir %{_libdir}/zlibrary/ui
%ghost %{_libdir}/zlibrary/ui/zlui-active.so
%{_libdir}/zlibrary/ui/zlui-qt4.so
%{_datadir}/zlibrary/keynames-qt4.xml

%changelog
* Tue Oct 16 2012 coolo@suse.com
- add explicit buildrequire on libbz2-devel
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Wed Aug 31 2011 kirill.kirillov@gmail.com
- cleaned spec using spec-cleaner
- fixed generic-name-not-in-filelist RPMLINT warning
* Tue Aug 23 2011 kirill.kirillov@gmail.com
- split zlibrary and zlibrary-ui packages (based on Fedora spec)
- used alternatives to select user interface (based of Fedora spec)
* Fri Dec 31 2010 kirill.kirillov@gmail.com
- added mime support (fbreader.xml)
* Tue Aug 17 2010 kirill.kirillov@gmail.com
- added fbreader-0.12.10-c++.patch to fix compilation (from archlinux)
* Tue Aug 17 2010 kirill.kirillov@gmail.com
- Update to 0.12.10
  + Processing of external hyperlinks in ePub files has been changed.
- Changes for 0.12.9
  + Processing of epub local hyperlinks of form ../dir/file.html has been fixed.
  + Code is now compilable with gcc 4.4.* (missing include directives have been added).
- Changes for 0.12.8
  + Smashwords library support has been improved: purchase links have been added.
  + LitRes library support has been updated: since this version FBReader uses an OPDS proxy located at http://data.fbreader.org/ for most operations with the LitRes catalog.
  + Processing of the xhtml hyperlinks in html encoded form (like /files/This%%20is%%20a%%20link) has been fixed.
  + A seg.fault during scanning several archives has been fixed.
  + Lithuanian localization has been updated.
  + Vietnamese language/encoding detection patterns have been added.
- Changes for 0.12.7
  + Vietnamese interface taranslation by Phạm Văn Hùng_Firestork has been added.
  + LitRes integration broken in the previous version has been fixed.
- Changes for 0.12.6
  + The viewing of ePub files from fictionwise.com has been fixed. A set of files from this site are compressed with some errors. However other readers (like Adobe Digital Editions) allows to read these books. FBReader 0.12.6 supports such books too.
* Sat Jan 16 2010 Kirill Kirillov <kirill.kirillov@gmail.com>
- Update to 0.12.1
  + Integration with LitRes.ru has been improved. A link for signing up has been added. A browsing by authors and by genres has been added.
  + Scrolling preferences have been simplified. Tap scrolling has been fixed.
  + Lithuanian localization has been added (thanks to Stanislovas Zacharovas).
  + Open file dialog behaviour has been fixed (in Gtk+ version).
  + A crach on some mobipocket files has been fixed.
* Thu Dec 10 2009 Kirill Kirillov <kirill.kirillov@gmail.com>
- Update to 0.12.0
  + New presentation of library.
  + Better integration with network libraries: FeedBooks, LitRes,
    Shucang and SmashWords. This version allows to browse catalogs,
    to search and download the books. For LitRes (Russian e-library)
    it is also possible to purchase books.
  + Added Chinese localization (by Shucang).
  + Image scaling has been implemented.
  + Better encoding/language detection. Arabic and Indonesian patterns are back.
  + Mobipocket, eReader and chm support have been improved.
* Sun Apr  5 2009 kirill.kirillov@gmail.com
- Update to 0.10.7
  + A conflict between hyperlink clicks and touch scrolling has been fixed
- Changes for 0.10.2
  + A bug with images/css links in epub has been fixed
* Sat Mar 21 2009 kirill.kirillov@gmail.com
- Update to 0.10.5
  + An FBReader freeze has been fixed
  + Several text selection related issues have been fixed
* Thu Mar 19 2009 kirill.kirillov@gmail.com
- Update to 0.10.4
  + Multiple fixes in the epub format support
* Wed Mar  4 2009 kirill.kirillov@gmail.com
- Update to 0.10.3
  + Some issues related to multi-file tar, tar.gz and tar.bz2
    archives have been fixed.
  + Greek hyphenation patterns were regenerated from another
    TeX source.
  + New version has no license issues from the Debian point of view
- Changes for 0.10.2
  + Images order in mobipocket files has been corrected.
  + Indonesian localization files have been updated.
- Changes for 0.10.1
  + Fixed an infinite loop in library building code.
  + Fixed <Space> key processing in qt4-based version.
  + Book description is visible for books found in network libraries.
* Tue Jan 13 2009 lars@linux-schulserver.de
- update to 0.10.0:
  + Network libraries integration has been added. FBReader can
    search and download books from Feedbooks.com and LitRes
    libraries.
  + Partial CSS support for epub files has been added.
    CSS support in html and fb2 is coming soon.
  + Epub and Mobipocket book formats support has been substantially
    improved.
  + Library view usability has been improved: you can now organize
    the tree either by author or by tag.
  + You can now select a word by double-click and a paragraph
    by triple-click.
  + Right-to-left languages and bidirectional texts support has
    been added (GNU FriBidi library is used).
  + Support for Arabic, Hebrew, Greek and Turkish has been added.
  + Czech localization has been added (many thanks to Lubomír Čevela).
  + FBReader now has a new set of icons.
  + It's now possible to use OS scrollbar for navigating through the
    text.
- add fribidi-devel, libcurl-devel, libqt4-devel to BuildRequires
- build gtk and qt4 ports
* Sun Nov 30 2008 lars@linux-schulserver.de
- require libexpat-devel on > 11.0
* Mon Sep 22 2008 lars@linux-schulserver.de
- moved to Education base repository
* Sun Mar 23 2008 kirill.kirillov@gmail.com
- Update to 0.8.17
  + Fixed crash after removing a book from library
  + Updated Finnish interface translation
* Sat Mar 22 2008 kirill.kirillov@gmail.com
- Update to 0.8.16
  + Book tags support has been added
  + The standard Unicode algorithm for line breaking in now used for
  all languages (including Chinese) provided by liblinebreak library
  + Fixed a bug with tapping scrolling/selection
* Mon Mar 17 2008 lars@linux-schulserver.de
- specfile beautify
- fix changelog
- use fdupes
- compress the source tarball
- use %%suse_update_desktopfile macro
- run /sbin/ldconfig
* Mon Mar 10 2008 kirill.kirillov@gmail.com
- Update to 0.8.15
  + Freeze during text scrolling has been fixed.
  + Indonesian localization (by Ketut Putu Kumajaya) has been added.
  + From now FBReader remembers list of recent search patterns.
- Changes for 0.8.14
  + Fixed crash. It was always reproducable for maemo platform and
  was possible for all othr platforms.
- Changes for 0.8.13
  + Freeze on several files has been fixed.
  + Plain text format support has been improved.
  + 'Go to page by number' feature has been added. In desktop version,
  this feature is assigned to 'G' key by default.
* Sun Jan 20 2008 kirill.kirillov@gmail.com
- Update to 0.8.12 bug fix release:
  + #44 "Undo" / "Redo" does not work
  + #73 "Go back" / "Go forward" does not work
  + #74 90%% of Books Loop back to page 3 after page 9/10
* Fri Jan 18 2008 kirill.kirillov@gmail.com
- Update to 0.8.11
  + Tap scrolling is now available for all platforms with touchscreen
  + XML namespace processing has been fixed in formats: oeb, epub, fb2
  + Plain text with UNIX line delimiters problem has been fixed
  + Default settings files are now human-readable
* Thu Jan 10 2008 kirill.kirillov@gmail.com
- Update to 0.8.10
* Sat Sep  1 2007 michel.sylvan@gmail.com
- Strip debugging info into separate subpackage
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Adjust file listing to accomodate changes from previous version
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Add missing BR: on libjpeg-devel (upstream documentation is misleading)
* Wed Aug 29 2007 michel.sylvan@gmail.com
- Update to 0.8.6b
* Sun Jul  1 2007 Wade Berrier <wberrier@gmail.com>
- Update to 0.8.4a
* Sun Jun  3 2007 Wade Berrier <wberrier@gmail.com>
- New package
